=======
History
=======


1.1.1 (2021-04-19)
------------------
* bug fix dataset download
* CTM is no longer verbose


1.1.0 (2021-04-18)
------------------
* New classification metrics
* Vocabulary downloader fix

1.0.2 (2021-04-16)
------------------
* Dataset downloader fix

1.0.0 (2021-04-16)
------------------
* New metrics initialization (do not support dictionaries as input anymore)
* Optimization, dataset and dashboard bug fixes
* Refactoring
* Updated README and documentation

0.4.0 (2021-04-15)
------------------
* Dataset preprocessing produces also an indexes.txt file containing the indexes of the documents
* Eval metrics bug fixes
* BBC news added in the correct format

0.3.0 (2021-04-10)
------------------
* Bug fixes

0.2.0 (2021-03-30)
------------------

* New dataset format


0.1.0 (2021-03-11)
------------------

* First release on PyPI.
